@@ -6,6 +6,7 @@
  */
 
 #include "filteractionsendfakedisposition.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <Akonadi/MDNStateAttribute>
 #include <KLocalizedString>
@@ -79,7 +80,7 @@ SearchRule::RequiredPart FilterActionSendFakeDisposition::requiredPart() const
 void FilterActionSendFakeDisposition::argsFromString(const QString &argsStr)
 {
     if (argsStr.length() == 1) {
-        if (argsStr[0] == QLatin1Char('I')) { // ignore
+        if (argsStr[0] == u'I') { // ignore
             mParameter = mParameterList.at(1);
             return;
         }
