@@ -8,13 +8,12 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FILTERACTIONWIDGET_H
-#define MAILCOMMON_FILTERACTIONWIDGET_H
+#pragma once
 
 #include "mailcommon_export.h"
 
 #include <Libkdepim/KWidgetLister>
-#include <QVector>
+#include <QList>
 namespace MailCommon
 {
 class FilterAction;
@@ -53,7 +52,7 @@ public:
     /**
      * Destroys the filter action widget.
      */
-    ~FilterActionWidget();
+    ~FilterActionWidget() override;
 
     /**
      * Sets the filter action.
@@ -73,7 +72,7 @@ public:
      * change during editing. Therefore the widget always creates a new
      * action object from the data in the combo box and returns that.
      */
-    Q_REQUIRED_RESULT MailCommon::FilterAction *action() const;
+    [[nodiscard]] MailCommon::FilterAction *action() const;
 
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
 
@@ -84,8 +83,8 @@ Q_SIGNALS:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class FilterActionWidgetPrivate;
+    std::unique_ptr<FilterActionWidgetPrivate> const d;
     //@endcond
 };
 
@@ -115,7 +114,7 @@ public:
     /**
      * Sets the @p list of filter actions, the lister will create FilterActionWidgets for.
      */
-    void setActionList(QVector<FilterAction *> *list);
+    void setActionList(QList<FilterAction *> *list);
 
     /**
      * Updates the action list according to the current action widget values.
@@ -150,11 +149,9 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    class FilterActionWidgetListerPrivate;
+    std::unique_ptr<FilterActionWidgetListerPrivate> const d;
     //@endcond
     void connectWidget(QWidget *widget, FilterAction *filterAction);
 };
 }
-
-#endif
